@@ -23,6 +23,9 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import queue
 
+from inspect import signature
+from typing import Any
+
 from injector import inject
 
 from refind_btrfs.common import CheckableObserver, constants
@@ -42,7 +45,14 @@ class SnapshotObserver(CheckableObserver):
 
         while self.should_keep_running():
             try:
-                self.dispatch_events(self.event_queue)
+                arguments: list[Any] = [self.event_queue]
+                dispatch_events_signature = signature(self.dispatch_events)
+                parameters = dispatch_events_signature.parameters
+                
+                if "timeout" in parameters:
+                    arguments.append(self.timeout)
+
+                self.dispatch_events(*arguments)
             except queue.Empty:
                 continue
             except SnapshotMountedAsRootError as e:
